@@ -23,7 +23,7 @@ int main()
 
     srv.add_controller(new hello_controller());
 
-    srv.bind("localhost", 8080);
+    srv.bind("::", 8080);
     srv.run(2);
 
     return 0;
