@@ -1,5 +1,5 @@
 // Copyright Maarten L. Hekkelman, Radboud University 2008-2013.
-//        Copyright Maarten L. Hekkelman, 2014-2020
+//        Copyright Maarten L. Hekkelman, 2014-2022
 //  Distributed under the Boost Software License, Version 1.0.
 //     (See accompanying file LICENSE_1_0.txt or copy at
 //           http://www.boost.org/LICENSE_1_0.txt)
@@ -13,6 +13,7 @@
 
 #include <memory>
 
+#include <boost/asio/streambuf.hpp>
 #include <boost/asio/posix/stream_descriptor.hpp>
 
 #include <zeep/http/message-parser.hpp>
@@ -20,7 +21,7 @@
 namespace zeep::http
 {
 
-class server;
+class basic_server;
 
 /// The HTTP server implementation of libzeep is inspired by the example code
 /// as provided by boost::asio. These objects are not to be used directly.
@@ -32,7 +33,7 @@ class connection
 	connection(connection &) = delete;
 	connection& operator=(connection &) = delete;
 
-	connection(boost::asio::io_service& service, server& handler);
+	connection(boost::asio::io_context& service, basic_server& handler);
 
 	void start();
 	void handle_read(boost::system::error_code ec, size_t bytes_transferred);
@@ -42,7 +43,7 @@ class connection
 
   private:
 	boost::asio::ip::tcp::socket m_socket;
-	server& m_server;
+	basic_server& m_server;
 	reply m_reply;
 	request_parser m_request_parser;
 	bool m_keep_alive = false;
