@@ -1,5 +1,5 @@
 // Copyright Maarten L. Hekkelman, Radboud University 2008-2013.
-//        Copyright Maarten L. Hekkelman, 2014-2020
+//        Copyright Maarten L. Hekkelman, 2014-2022
 // Distributed under the Boost Software License, Version 1.0.
 //    (See accompanying file LICENSE_1_0.txt or copy at
 //          http://www.boost.org/LICENSE_1_0.txt)
@@ -96,7 +96,7 @@ class node
 	///
 	/// To reduce storage requirements, names are stored in nodes as qnames, if at all.
 	virtual std::string get_qname() const;
-	virtual void set_qname(const std::string& qn)
+	virtual void set_qname(const std::string& /*qn*/)
 	{
 		assert(false);
 	}
@@ -218,7 +218,7 @@ class comment : public node_with_text
 {
   public:
 	comment() {}
-	comment(comment&& c) : node_with_text(std::move(c.m_text)) {}
+	comment(comment&& c) noexcept : node_with_text(std::move(c.m_text)){}
 	comment(const std::string& text) : node_with_text(text) {}
 
 	/// \brief compare nodes for equality
@@ -240,7 +240,7 @@ class processing_instruction : public node_with_text
   public:
 	processing_instruction() {}
 
-	processing_instruction(processing_instruction&& pi)
+	processing_instruction(processing_instruction&& pi) noexcept
 		: node_with_text(std::move(pi.m_text))
 		, m_target(std::move(pi.m_target))
 	{}
@@ -284,7 +284,7 @@ class text : public node_with_text
   public:
 	text() {}
 
-	text(text&& t)
+	text(text&& t) noexcept
 		: node_with_text(std::move(t.m_text)) {}
 
 	text(const std::string& text)
@@ -316,7 +316,7 @@ class cdata : public text
 {
   public:
 	cdata() {}
-	cdata(cdata&& cd) : text(std::move(cd)) {}
+	cdata(cdata&& cd) noexcept : text(std::move(cd)) {}
 	cdata(const std::string& s)	: text(s) {}
 
 	/// \brief compare nodes for equality
@@ -341,15 +341,15 @@ class attribute : public node
 	using parent_type = element;
 
 	attribute(const attribute& attr)
-		: m_qname(attr.m_qname), m_value(attr.m_value), m_id(attr.m_id) {}
+		: node(), m_qname(attr.m_qname), m_value(attr.m_value), m_id(attr.m_id) {}
 
-	attribute(attribute&& attr)
-		: m_qname(std::move(attr.m_qname)), m_value(std::move(attr.m_value)), m_id(attr.m_id) {}
+	attribute(attribute&& attr) noexcept
+		: node(), m_qname(std::move(attr.m_qname)), m_value(std::move(attr.m_value)), m_id(attr.m_id) {}
 
 	attribute(const std::string& qname, const std::string& value, bool id = false)
 		: m_qname(qname), m_value(value), m_id(id) {}
 	
-	attribute& operator=(attribute&& attr)
+	attribute& operator=(attribute&& attr) noexcept
 	{
 		std::swap(m_qname, attr.m_qname);
 		std::swap(m_value, attr.m_value);
@@ -523,7 +523,7 @@ class iterator_impl
 #endif
 	}
 
-	iterator_impl(iterator_impl&& i)
+	iterator_impl(iterator_impl&& i) noexcept
 		: m_container(i.m_container)
 		, m_current(i.m_current)
 		, m_at_end(i.m_at_end)
@@ -552,7 +552,7 @@ class iterator_impl
 		return *this;
 	}
 
-	iterator_impl& operator=(iterator_impl&& i)
+	iterator_impl& operator=(iterator_impl&& i) noexcept
 	{
 		if (this != &i)
 		{
@@ -691,7 +691,7 @@ class iterator_impl
 		return std::distance(*this, other);
 	}
 
-	operator const pointer() const	{ return current(); }
+	operator pointer() const		{ return current(); }
 	operator pointer()				{ return current(); }
 
   private:
@@ -976,7 +976,7 @@ class node_list : public basic_node_list<node>
 		return *this;
 	}
 
-	node_list& operator=(node_list&& l)
+	node_list& operator=(node_list&& l) noexcept
 	{
 		if (this != &l)
 		{
@@ -1164,7 +1164,7 @@ class attribute_set : public basic_node_list<attribute>
 		return *this;
 	}
 
-	attribute_set& operator=(attribute_set&& l)
+	attribute_set& operator=(attribute_set&& l) noexcept
 	{
 		if (this != &l)
 		{
@@ -1381,15 +1381,27 @@ class element : public node
 	}
 
 	/// \brief insert the data of node \a n at position \a pos, using move semantics
-	template<typename N, std::enable_if_t<
-		std::is_same_v<std::remove_reference_t<N>, text> or
-		std::is_same_v<std::remove_reference_t<N>, cdata> or
-		std::is_same_v<std::remove_reference_t<N>, comment> or
-		std::is_same_v<std::remove_reference_t<N>, processing_instruction>,
-		int> = 0>
-	iterator emplace(const_iterator pos, N&& n)
+	iterator emplace(const_iterator pos, text&& n)
 	{
-		return insert_impl(pos, new N(std::forward<N>(n)));
+		return insert_impl(pos, new text(std::forward<text>(n)));
+	}
+
+	/// \brief insert the data of node \a n at position \a pos, using move semantics
+	iterator emplace(const_iterator pos, cdata&& n)
+	{
+		return insert_impl(pos, new cdata(std::forward<cdata>(n)));
+	}
+
+	/// \brief insert the data of node \a n at position \a pos, using move semantics
+	iterator emplace(const_iterator pos, comment&& n)
+	{
+		return insert_impl(pos, new comment(std::forward<comment>(n)));
+	}
+
+	/// \brief insert the data of node \a n at position \a pos, using move semantics
+	iterator emplace(const_iterator pos, processing_instruction&& n)
+	{
+		return insert_impl(pos, new processing_instruction(std::forward<processing_instruction>(n)));
 	}
 
 	/// \brief emplace a newly constructed element at \a pos using argument \a arg
