@@ -1,5 +1,5 @@
 // Copyright Maarten L. Hekkelman, Radboud University 2008-2013.
-//        Copyright Maarten L. Hekkelman, 2014-2020
+//        Copyright Maarten L. Hekkelman, 2014-2022
 //   Distributed under the Boost Software License, Version 1.0.
 //      (See accompanying file LICENSE_1_0.txt or copy at
 //            http://www.boost.org/LICENSE_1_0.txt)
@@ -17,6 +17,7 @@
 #include <zeep/unicode-support.hpp>
 #include <zeep/http/el-processing.hpp>
 #include <zeep/http/server.hpp>
+#include <zeep/http/uri.hpp>
 
 #include "format.hpp"
 
@@ -660,7 +661,7 @@ void interpreter::get_next_token()
 				m_token_number_int = 10 * m_token_number_int + (ch - '0');
 			else if (ch == '.')
 			{
-				m_token_number_float = m_token_number_int;
+				m_token_number_float = static_cast<double>(m_token_number_int);
 				fraction = 0.1;
 				state = State::NumberFraction;
 			}
@@ -1567,7 +1568,7 @@ class number_expr_util_object : public expression_utility_object<number_expr_uti
 
 				double d;
 				if (params[0].is_number_int())
-					d = params[0].as<int64_t>();
+					d = static_cast<double>(params[0].as<int64_t>());
 				else
 					d = params[0].as<double>();
 
@@ -1737,7 +1738,7 @@ scope::scope(const request &req)
 {
 }
 
-scope::scope(const server& server, const request &req)
+scope::scope(const basic_server& server, const request &req)
 	: m_next(nullptr), m_depth(0), m_req(&req), m_server(&server)
 {
 }
