@@ -1,3 +1,5 @@
+#include <boost/asio.hpp>
+
 #define BOOST_TEST_MODULE Processor_Test
 #include <boost/test/included/unit_test.hpp>
 
@@ -8,7 +10,9 @@
 
 using namespace std;
 
+#ifndef DOCROOT
 #define DOCROOT "./lib-http/test/"
+#endif
 
 using json = zeep::json::element;
 using namespace zeep::xml::literals;
@@ -388,7 +392,7 @@ BOOST_AUTO_TEST_CASE(test_14)
 
 		process_and_compare(doc, doc_test, scope);
 	}
-	catch (const std::runtime_error& e)
+	catch (const std::runtime_error&)
 	{
 		std::cerr << "skipping test 14 since locale nl_NL.UTF-8 is not available" << std::endl;
 	}
@@ -423,7 +427,7 @@ BOOST_AUTO_TEST_CASE(test_15)
 
 		process_and_compare(doc, doc_test, scope);
 	}
-	catch (const std::runtime_error& e)
+	catch (const std::runtime_error&)
 	{
 		std::cerr << "skipping test 15 since locale da_DK.UTF-8 is not available" << std::endl;
 	}
@@ -457,7 +461,7 @@ BOOST_AUTO_TEST_CASE(test_16)
 
 		process_and_compare(doc, doc_test, scope);
 	}
-	catch (const std::runtime_error& e)
+	catch (const std::runtime_error&)
 	{
 		std::cerr << "skipping test 16 since locale en_GB.UTF-8 is not available" << std::endl;
 	}
@@ -1068,3 +1072,55 @@ BOOST_AUTO_TEST_CASE(test_34)
 
 	process_and_compare(doc, doc_test, scope);
 }
+
+BOOST_AUTO_TEST_CASE(test_35)
+{
+	auto doc = R"xml(<?xml version="1.0"?>
+<data xmlns:z="http://www.hekkelman.com/libzeep/m2">
+<span z:inline="text">test [(${a}.${b})]</span>
+</data>
+	)xml"_xml;
+
+	auto doc_test = R"(<?xml version="1.0"?>
+<data>
+<span>test Error processing ${a}.${b}</span>
+</data>
+	)"_xml;
+
+	zeep::http::scope scope;
+
+	scope.put("a", "aap");
+	scope.put("b", "noot");
+
+	zeep::http::template_processor p(DOCROOT);
+	zeep::http::tag_processor_v2 tp;
+
+	process_and_compare(doc, doc_test, scope);
+}
+
+BOOST_AUTO_TEST_CASE(test_36)
+{
+	auto doc = R"xml(<?xml version="1.0"?>
+<data xmlns:z="http://www.hekkelman.com/libzeep/m2">
+<span z:classappend="${x ge 1.5 ? 'greater-equal'}"></span>
+<span z:classappend="${x le 1.5 ? 'less-equal'}"></span>
+</data>
+	)xml"_xml;
+
+	auto doc_test = R"(<?xml version="1.0"?>
+<data>
+<span class="greater-equal"></span>
+<span/>
+</data>
+	)"_xml;
+
+	zeep::http::scope scope;
+
+	scope.put("x", 2.0);
+
+	zeep::http::template_processor p(DOCROOT);
+	zeep::http::tag_processor_v2 tp;
+
+	process_and_compare(doc, doc_test, scope);
+}
+
