@@ -1,18 +1,15 @@
 // Copyright Maarten L. Hekkelman, Radboud University 2008-2013.
-//        Copyright Maarten L. Hekkelman, 2014-2020
+//        Copyright Maarten L. Hekkelman, 2014-2022
 // Distributed under the Boost Software License, Version 1.0.
 //    (See accompanying file LICENSE_1_0.txt or copy at
 //          http://www.boost.org/LICENSE_1_0.txt)
 
 #include <set>
-
-#include <boost/algorithm/string.hpp>
+#include <stack>
 
 #include <zeep/xml/document.hpp>
 #include <zeep/xml/xpath.hpp>
 
-namespace ba = boost::algorithm;
-
 namespace zeep::xml
 {
 
@@ -34,7 +31,7 @@ void write_string(std::ostream& os, const std::string& s, bool escape_whitespace
 		auto sb = sp;
 
 		unicode c;
-		std::tie(c, sp) = get_first_char(sp);
+		std::tie(c, sp) = get_first_char(sp, se);
 
 		switch (c)
 		{
@@ -51,7 +48,7 @@ void write_string(std::ostream& os, const std::string& s, bool escape_whitespace
 							for (auto ci = sb; ci < sp; ++ci)
 								os << *ci;
 						else
-							os << "&#" << c << ';';
+							os << "&#" << static_cast<int>(c) << ';';
 						last_is_space = false;
 						break;
 		}
@@ -330,10 +327,10 @@ bool text::equals(const node* n) const
 	if (t != nullptr)
 	{
 		std::string text = m_text;
-		ba::trim(text);
+		trim(text);
 
 		std::string ttext = t->m_text;
-		ba::trim(ttext);
+		trim(ttext);
 
 		result = text == ttext;
 	}
@@ -518,7 +515,8 @@ element::element(const std::string& qname, std::initializer_list<zeep::xml::attr
 
 // copy constructor. Copy data and children, but not parent and sibling
 element::element(const element& e)
-	: m_qname(e.m_qname)
+	: node()
+	, m_qname(e.m_qname)
 	, m_nodes(*this, e.m_nodes)
 	, m_attributes(*this, e.m_attributes)
 {
@@ -666,39 +664,39 @@ bool element::equals(const node* n) const
 			result = m_attributes == e->m_attributes;
 			if (not result)
 			{
-				std::set<attribute> a(m_attributes.begin(), m_attributes.end());
-				std::set<attribute> b(e->m_attributes.begin(), e->m_attributes.end());
+				std::set<attribute> as(m_attributes.begin(), m_attributes.end());
+				std::set<attribute> bs(e->m_attributes.begin(), e->m_attributes.end());
 
 				std::set<std::string> nsa, nsb;
 
-				auto ai = a.begin(), bi = b.begin();
+				auto ai = as.begin(), bi = bs.begin();
 				for (;;)
 				{
-					if (ai == a.end() and bi == b.end())
+					if (ai == as.end() and bi == bs.end())
 						break;
 					
-					if (ai != a.end() and ai->is_namespace())
+					if (ai != as.end() and ai->is_namespace())
 					{
 						nsa.insert(ai->value());
 						++ai;
 						continue;
 					}
 
-					if (bi != b.end() and bi->is_namespace())
+					if (bi != bs.end() and bi->is_namespace())
 					{
 						nsb.insert(bi->value());
 						++bi;
 						continue;
 					}
 
-					if (ai == a.end() or bi == b.end() or *ai++ != *bi++)
+					if (ai == as.end() or bi == bs.end() or *ai++ != *bi++)
 					{
 						result = false;
 						break;
 					}
 				}
 
-				result = ai == a.end() and bi == b.end() and nsa == nsb;
+				result = ai == as.end() and bi == bs.end() and nsa == nsb;
 			}
 		}
 	}
@@ -951,9 +949,9 @@ void element::move_to_name_space(const std::string& prefix, const std::string& u
 			if (not attr.is_namespace())
 				continue;
 			
-			auto p = prefix_for_namespace(attr.uri());
-			if (not p.second)
-				attr.set_qname("xmlns", p.first);
+			auto nsp = prefix_for_namespace(attr.uri());
+			if (not nsp.second)
+				attr.set_qname("xmlns", nsp.first);
 		}
 
 		// ... and then the others, makes sure the namespaces are known
@@ -968,10 +966,10 @@ void element::move_to_name_space(const std::string& prefix, const std::string& u
 				attr.set_qname(prefix + ':' + attr.name());
 			else
 			{
-				auto p = prefix_for_namespace(ns);
-				if (not p.second)
+				auto nsp = prefix_for_namespace(ns);
+				if (not nsp.second)
 					throw exception("Cannot move element to new namespace, namespace not found: " + ns);
-				attr.set_qname(p.first, attr.name());
+				attr.set_qname(nsp.first, attr.name());
 			}
 		}
 	}
@@ -1024,20 +1022,20 @@ void fix_namespaces(element& e, element& source, element& dest)
 
 	while (not s.empty())
 	{
-		auto e = s.top();
+		auto n = s.top();
 		s.pop();
 
-		auto p = e->get_prefix();
+		auto p = n->get_prefix();
 		if (not p.empty())
 		{
 			if (mapped.count(p))
 			{
 				if (mapped[p] != p)
-					e->set_qname(mapped[p], e->name());
+					n->set_qname(mapped[p], n->name());
 			}
 			else
 			{
-				auto ns = e->namespace_for_prefix(p);
+				auto ns = n->namespace_for_prefix(p);
 				if (ns.empty())
 					ns = source.namespace_for_prefix(p);
 
@@ -1045,7 +1043,7 @@ void fix_namespaces(element& e, element& source, element& dest)
 				if (dp.second)
 				{
 					mapped[p] = dp.first;
-					e->set_qname(dp.first, e->name());
+					n->set_qname(dp.first, n->name());
 				}
 				else
 				{
@@ -1055,7 +1053,7 @@ void fix_namespaces(element& e, element& source, element& dest)
 			}
 		}
 
-		auto el = dynamic_cast<element*>(e);
+		auto el = dynamic_cast<element*>(n);
 		if (el == nullptr)
 			continue;
 
